/*
* Copyright (c) 2004-2006 Weswit s.r.l., Via Campanini, 6 - 20124 Milano, Italy.
* All rights reserved.
* www.lightstreamer.com
*
* This software is the confidential and proprietary information of
* Weswit s.r.l.
* You shall not disclose such Confidential Information and shall use it
* only in accordance with the terms of the license agreement you entered
* into with Weswit s.r.l.
*/

using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Threading;
using System.Globalization;
using System.Runtime.InteropServices;

using Lightstreamer.DotNet.Client;

namespace Nms.DotNet.Client.Demo {

    public delegate void LightstreamerUpdateDelegate(int item, string[] values);
    public delegate void LightstreamerStatusChangedDelegate(string status);

    public delegate void StopDelegate();
    public delegate void BlinkOffDelegate(DataGridViewCell[] cells);

    public partial class DemoForm : Form, IMessageFilter {

        private NmsClient nmsClient;

#region API Declarations

        [DllImport("user32.dll")]
        private static extern int GetSystemMenu(int hwnd, bool bRevert);

        [DllImport("user32.dll")]
        private static extern long AppendMenuA(int hMenu, int wFlags, int wIDNewItem, string lpNewItem);

        [DllImport("user32.dll")]
        private static extern long RemoveMenu(int hMenu, int nPosition, int wFlags);

        private const int MF_BYPOSITION = 1024;
        private const int MF_SEPERATOR = 2048;
        private const int MF_REMOVE = 4096;
        private const int WM_SYSCOMMAND = 274;
        private const int WM_KEYDOWN = 256;

#endregion // API Declarations

        public DemoForm() {
            nmsClient = null;

            InitializeComponent();
        }

        private void OnFormLoaded(object sender, EventArgs e) {
            statusProgressbar.Style = ProgressBarStyle.Marquee;
            statusProgressbar.Enabled = true;

            Thread t = new Thread(new ThreadStart(StartLightstreamer));
            t.Start();
        }

        private void OnFormClosed(object sender, FormClosedEventArgs e) {
            Environment.Exit(0);
        }
        
        private void LightstreamerStopped() {
            statusProgressbar.Style = ProgressBarStyle.Blocks;
            statusProgressbar.Enabled = false;
        }

        private void StartLightstreamer() {
            nmsClient = new NmsClient(
                this,
                new LightstreamerUpdateDelegate(OnLightstreamerUpdate),
                new LightstreamerStatusChangedDelegate(OnLightstreamerStatusChanged));

            try {
//                nmsClient.Start("http://push.lightstreamer.com");
                nmsClient.Start("http://localhost:8080");
            }
            catch (System.Exception e) {
                nmsClient = null;

                Invoke(new StopDelegate(LightstreamerStopped));

                MessageBox.Show(
                    e.ToString(),
                    "Error",
                    MessageBoxButtons.OK,
                    MessageBoxIcon.Information);
            }
        }

        private void OnLightstreamerUpdate(int item, string[] values) {
            if (item == 1)
            {
                ChangeStatus(this.equipment1Button, values[1]);
            } else if (item == 2)
            {
                ChangeStatus(this.equipment2Button, values[1]);
            }
            else if (item == 3)
            {
                ChangeStatus(this.equipment3Button, values[1]);
            }
        }

  
        private void ChangeStatus(Button equip, string strStatus)
        {
            int status = int.Parse(strStatus);
            switch (status)
            {
                case 1:
                    equip.BackColor = System.Drawing.Color.Green;
                    break;
                case 2:
                    equip.BackColor = System.Drawing.Color.Yellow;
                    break;
                case 3:
                    equip.BackColor = System.Drawing.Color.Red;
                    break;
                default:
                    break;
            }
        }
        private void OnLightstreamerStatusChanged(string status) {
            statusLabel.Text = status;
        }


        public bool PreFilterMessage(ref Message msg)
        {
            return false;
        } 

    }

}