/*
* Copyright (c) 2004-2006 Weswit s.r.l., Via Campanini, 6 - 20124 Milano, Italy.
* All rights reserved.
* www.lightstreamer.com
*
* This software is the confidential and proprietary information of
* Weswit s.r.l.
* You shall not disclose such Confidential Information and shall use it
* only in accordance with the terms of the license agreement you entered
* into with Weswit s.r.l.
*/

using System;
using System.Collections.Generic;
using System.Text;

using Lightstreamer.DotNet.Client;

namespace Nms.DotNet.Client.Demo {

    class NmsConnectionListener : IConnectionListener {
        private DemoForm demoForm;
        private LightstreamerUpdateDelegate updateDelegate;
        private LightstreamerStatusChangedDelegate statusChangeDelegate;

        public NmsConnectionListener(
                DemoForm form,
                LightstreamerUpdateDelegate lsUpdateDelegate,
                LightstreamerStatusChangedDelegate lsStatusChangeDelegate) {
            
            demoForm = form;
            updateDelegate = lsUpdateDelegate;
            statusChangeDelegate = lsStatusChangeDelegate;
        }

        public void OnConnectionEstablished() {
            string status = "Connected to Lightstreamer Server...";
            demoForm.Invoke(statusChangeDelegate, new Object[] { status });
        }

        public void OnSessionStarted() {
            string status = "Lightstreamer is pushing...";
            demoForm.Invoke(statusChangeDelegate, new Object[] { status });
        }

        public void OnNewBytes(long b) {}

        public void OnDataError(PushServerException e) {
            string status = "Data error";
            demoForm.Invoke(statusChangeDelegate, new Object[] { status });
        }

        public void OnActivityWarning(bool warningOn) {
            if (warningOn) {
                string status = "Connection stalled";
                demoForm.Invoke(statusChangeDelegate, new Object[] { status });
            }
            else {
                string status = "Connection no longer stalled";
                demoForm.Invoke(statusChangeDelegate, new Object[] { status });
            }
        }

        public void OnClose() {
            string status = "Connection closed";
            demoForm.Invoke(statusChangeDelegate, new Object[] { status });
        }

        public void OnFailure(PushServerException e) {
            string status = "Server failure";
            demoForm.Invoke(statusChangeDelegate, new Object[] { status });
        }

        public void OnFailure(PushConnException e) {
            string status = "Connection failure";
            demoForm.Invoke(statusChangeDelegate, new Object[] { status });
        }
    }

}
